/*
 * LibSKK, a tiny Library to emulate SKK (Simple Kana Kanji Conversion)
 * 
 * Copyright (C) 2002 Motonobu Ichimura <famao@kondara.org>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, provided that the above
 * copyright notice(s) and this permission notice appear in all copies of
 * the Software and that both the above copyright notice(s) and this
 * permission notice appear in supporting documentation.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT
 * OF THIRD PARTY RIGHTS. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 * HOLDERS INCLUDED IN THIS NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL
 * INDIRECT OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING
 * FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
 * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale, use
 * or other dealings in this Software without prior written authorization
 * of the copyright holder.
 *
 */

/* $Id: skkdictitem.h,v 1.5 2004/05/03 04:23:49 famao Exp $ */

/* vi:set ts=4 sw=4: */


#ifndef HAVE_SKK_DICT_ITEM_H
#define HAVE_SKK_DICT_ITEM_H

#include <glib.h>

typedef struct _SkkDictItem SkkDictItem;

struct _SkkDictItem
{
	gchar *candidate;
	gchar *annotation;
	guint flag;
};

SkkDictItem *skk_dict_item_new (void);
SkkDictItem *skk_dict_item_new_with_value (const gchar *candidate, const gchar *annotation);
SkkDictItem *skk_dict_item_new_with_string (const gchar *string, const gchar *delim);
GList *skk_dict_item_new_from_line (const gchar *line, const gchar *delim, const gchar *annotate_delim);
void skk_dict_item_destroy (SkkDictItem *item);
void skk_dict_item_destroy_all (GList *list);
GList *skk_dict_item_merge_list (GList *list1, GList *list2);
gchar *skk_dict_item_to_string_all (GList *list, const gchar *sep, const gchar *delim);
gchar *skk_dict_item_to_string (SkkDictItem *item, const gchar *delim);


#endif
